import {message} from "antd"
import ArticleBlock from "@/components/article/block.tsx";

import styles from './article.module.scss'
import {showToast} from "@/components/message.ts";

type Props = {
	groups: BlockContent[][];
	editable?: boolean;
	onChange?: (groups: BlockContent[][]) => void;
	errorMessage?: string;
}



export default function ArticleGroup({groups, editable, onChange, errorMessage}: Props) {
	// const groups = rebuildGroups(_groups)
	/**
	 * 添加一个组
	 * @param insertIndex 插入的位置，-1表示插入到末尾
	 */
	const handleAddGroup = (insertIndex: number = -1) => {
		if (insertIndex !== -1 && insertIndex !== 1) {
			const triggerGroup = insertIndex == -1 || insertIndex >= groups.length ? groups[groups.length - 1] : groups[insertIndex - 1];
			// 判断
			if (triggerGroup.length == 0 || triggerGroup.some(s => !s.content)) {
				showToast('请先添加内容')
				return;
			}
		}

		const newGroup: BlockContent[] = [{type: 'text', content: ''}]
		const _groups = [...groups];
		if (insertIndex == -1 || insertIndex >= groups.length) { // -1或者越界表示新增
			_groups.push(newGroup)
		} else {
			_groups.splice(insertIndex, 0, newGroup)
		}
		onChange?.(_groups)
	}
	return <div className={styles.group}>
		{groups.map((g, index) => (
			<ArticleBlock
				editable={editable}
				key={index}
				blocks={g}
				onChange={(blocks) => {
					groups[index] = blocks
					onChange?.([...groups])
				}}
				errorMessage={errorMessage}
				index={index}
				onAdd={() => {
					handleAddGroup?.(index + 1)
				}}
				onRemove={async () => {
					if (groups.length == 1) {
						message.warning('至少保留一个内容块')
						return;
					}
					onChange?.(groups.filter((_, idx) => index !== idx))
				}}
			/>
		))}
		{groups.length == 0 && editable &&
            <ArticleBlock editable onChange={blocks => onChange?.([blocks])} index={0}
                          blocks={[{type: 'text', content: ''}]}/>}
	</div>
}