import {useSortable} from "@dnd-kit/sortable";
import {useSetState} from "ahooks";
import React, {useEffect} from "react";
import {clsx} from "clsx";
import {Popconfirm} from "antd";
import {CheckCircleFilled, MenuOutlined, MinusCircleFilled,LoadingOutlined} from "@ant-design/icons";

import ImageCover from '@/assets/images/cover.png'
import {IconEdit, IconPlay} from "@/components/icons";
import {VideoStatus} from "@/service/api/video.ts";

type Props = {
	video: VideoInfo | LiveVideoInfo,
	editable?: boolean;
	sortable?: boolean;
	index?: number;
	checked?: boolean;
	active?: boolean;
	onCheckedChange?: (checked: boolean) => void;
	onPlay?: () => void;
	onEdit?: () => void;
	onRemove?: () => void;
	id: number;
	className?: string;
	type?:'live'|'create'
}

export const VideoListItem = (
	{
		id, video, onPlay, onRemove, checked,
		onCheckedChange, onEdit, active, editable,
		className, sortable,type
	}: Props) => {
	const {
		attributes, listeners,
		setNodeRef, transform
	} = useSortable({resizeObserverConfig: {}, id})


	const [state, setState] = useSetState<{ checked?: boolean }>({})
	useEffect(() => {
		setState({checked})
	}, [checked])

	return <div
		className={`video-item flex items-center gap-3 ${className}`}
		ref={setNodeRef} style={{transform: `translateY(${transform?.y || 0}px)`,}}>
		{/*{index && index > 0 && <div className="flex items-center px-2">*/}
		{/*    <div className="index-value w-[40px] h-[40px] flex items-center justify-center bg-gray-100 rounded-3xl">{index}</div>*/}
		{/*</div>}*/}
		<div
			className={`video-item-info relative flex gap-2 flex-1 bg-gray-100 h-[80px] overflow-hidden rounded-lg p-3 shadow-blue-500 ${active ? 'video-item-shadow' : ''}`}>
			<div className={'video-title leading-7 flex-1'}>{video.title || video.video_title}</div>
			<div className={'video-item-cover bg-white rounded-md overflow-hidden'}>
				<img className="w-[100px] h-[56px] object-cover" src={video.cover || ImageCover} />
			</div>
			{type == 'create' && video.status == VideoStatus.Generating && <div className={'absolute inset-0 bg-black/30 text-white flex items-center justify-center'}>
                <span className="ml-1">视频生成中</span>
			</div>}
		</div>
		<div className="operation flex items-center ml-2 gap-3 text-lg text-gray-400 w-[116px]">
			{sortable && (!active ? <button className="hover:text-blue-500 cursor-move" {...attributes} {...listeners}>
				<MenuOutlined/>
			</button> : <button disabled className="cursor-not-allowed"><MenuOutlined/></button>)}
			{onPlay &&<button className="hover:text-blue-500" onClick={onPlay} style={{fontSize: '1.3em'}}><IconPlay/></button>}

			{editable && <>
				{onEdit &&
                    <button className="hover:text-blue-500" onClick={onEdit} style={{fontSize: '1.1em'}}><IconEdit/>
                    </button>}
                <button className="hover:text-blue-300" onClick={() => {
					if (onCheckedChange) {
						onCheckedChange(!state.checked)
					} else {
						setState({checked: !state.checked})
					}
				}}><CheckCircleFilled className={clsx({'text-blue-500': state.checked})}/></button>
				{onRemove && <Popconfirm
                    title={<div style={{minWidth: 150}}><span>请确认删除此视频?</span></div>}
                    onConfirm={onRemove}
                    okText="删除"
                    cancelText="取消"
                >
                    <button className="hover:text-blue-500"><MinusCircleFilled/></button>
                </Popconfirm>}
            </>}
		</div>
	</div>
}