import {Button, Input} from "antd";
import {SearchOutlined} from "@ant-design/icons";
import ArticleCascader from "@/pages/news/components/article-cascader.tsx";
import React, {useState} from "react";
import {useSetState} from "ahooks";
import useArticleTags from "@/hooks/useArticleTags.ts";

export default function EditSearchForm(props: {
	onSubmit: (values: ApiArticleSearchParams) => void;
}) {
	const articleTags = useArticleTags()
	const [tags, setTags] = useState<Id[][]>([]);
	const [params, setParams] = useSetState<ApiArticleSearchParams>({
		pagination: {limit: 10, page: 1},
	});

	const handleSubmit = () => {
		params.tags = tags.length == 0 ? undefined : tags.map(it => {
			if (Array.isArray(it)) {
				return {
					level1: it[0],
					level2: it.length == 2 ? it[1] : 0
				}
			} else {
				return {
					level1: it, level2: 0
				}
			}
		});
		props.onSubmit({
			...params,
			pagination: {
				page: 1,
				limit: 10
			}
		})
	}
	return (
		<div className="search-form-input flex gap-2 items-center">
			<Input
				onChange={(e) => {
					setParams({title: e.target.value})
				}}
				allowClear
				type="text" className="rounded px-3 w-[250px]"
				suffix={<SearchOutlined/>}
				placeholder="请输入你先搜索的关键词"
			/>
			<span className="ml-5 text-sm">来源</span>
			<ArticleCascader
				options={articleTags}
				onChange={setTags}
			/>
			<Button type="primary" onClick={handleSubmit}>搜索</Button>
		</div>
	)
}