import {Button, Input, Select} from "antd";
import {useSetState} from "ahooks";
import {useState} from "react";
import useArticleTags from "@/hooks/useArticleTags.ts";

import {SearchListTimes} from "@/pages/news/components/news-source.ts";

type SearchPanelProps = {
	onSearch?: (params: ApiArticleSearchParams) => void;
}
const pagination = {
	limit: 10, page: 1
}
const DEFAULT_STATE = {
	tag_level_1_id: -1,
	tag_level_2_id: -1,
	subOptions: []
}
export default function SearchPanel({onSearch}: SearchPanelProps) {
	const tags = useArticleTags();
	const [params, setParams] = useSetState<ApiArticleSearchParams>({
		pagination
	});

	const [state, setState] = useSetState<{
		tag_level_1_id: number;
		tag_level_2_id: number;
		subOptions: (string | number)[]
	}>({...DEFAULT_STATE})

	// 二级分类
	const [subOptions, setSubOptions] = useState<OptionItem[]>([])
	const onFinish = () => {

		onSearch?.({
			...params,
			tag_level_1_id: state.tag_level_1_id > 0?state.tag_level_1_id:undefined,
			tag_level_2_id: state.tag_level_2_id > 0?state.tag_level_2_id:undefined,
			pagination
		})
	}
	// 重置
	const onReset = () => {
		setParams({pagination, title: ''})
		setState({...DEFAULT_STATE})
		setSubOptions([])
		onSearch?.({pagination})
	}

	return (<div className={'search-panel'}>
		<div className="flex justify-between items-center">
			<div className="search-form flex items-center gap-4">
				<Input
					value={params.title}
					onChange={e => setParams({title: e.target.value})}
					className="w-[240px]"
					placeholder={'请输入新闻标题开始查找新闻'}
				/>
				<div className={'flex items-center ml-2'}>
					<span className="text-sm whitespace-nowrap mr-1">更新时间</span>
					<Select
						className="w-[150px]"
						value={params.time_flag || 0}
						onChange={value => setParams({time_flag: value})}
						options={SearchListTimes}
						optionRender={(option) => (
							<div className="flex items-center">
								<span role="icon" className={`radio-icon`}></span>
								<span role="listitem" aria-label={String(option.label)}>{option.label}</span>
							</div>
						)}
					/>
				</div>
				<Button type={'primary'} onClick={onFinish}>搜索</Button>
				<Button onClick={onReset}>重置</Button>
			</div>
		</div>
		<div className="filter-container flex items-start mt-5">
			<div className="list-container flex-1">
				<div className="news-source-lv-1 flex flex-wrap">
					<div
						className={`filter-item whitespace-nowrap px-2 py-1 mt-1 text-sm mr-1 cursor-pointer rounded ${state.tag_level_1_id == -1 ? 'bg-blue-500 text-white' : 'hover:bg-gray-100'}`}
						onClick={() => {
							setState({...DEFAULT_STATE})
							setSubOptions([])
						}}>全部</div>
					{
						tags.filter(s=>s.value !== 999999).map(it => (
							<div
								className={`filter-item whitespace-nowrap px-2 py-1 mt-1 text-sm mr-1 cursor-pointer rounded ${state.tag_level_1_id == it.value ? 'bg-blue-500 text-white' : 'hover:bg-gray-100'}`}
								key={it.value}
								onClick={() => {
									setState({tag_level_1_id: Number(it.value),tag_level_2_id:-1})
									setSubOptions(it.children || [])
								}}>{it.label}</div>)
						)
					}
				</div>
				{state.tag_level_1_id != -1 && subOptions.length > 0 && <div className="news-source-lv-2 bg-gray-100 p-2 rounded mt-2 flex flex-wrap">
					{
						subOptions.map(it => (
							<div
								className={`filter-item whitespace-nowrap px-2 py-1 mt-1 text-sm mr-1 cursor-pointer rounded ${state.tag_level_2_id == it.value ? 'bg-blue-500 text-white' : 'hover:bg-gray-100'}`}
								key={it.value}
								onClick={() => {
									setState({tag_level_2_id: Number(it.value)})
								}}>{it.label}</div>)
						)
					}
                </div>}
			</div>

		</div>
	</div>)
}