import {Button, Pagination, Table, TableColumnsType, TableProps, Typography} from "antd";

import {Card} from "@/components/card";
import React, {useState} from "react";
import {useRequest} from "ahooks";
import {formatTime} from "@/util/strings.ts";
import ArticleEditModal from "@/components/article/edit-modal.tsx";
import {getList} from "@/service/api/article.ts";
import EditSearchForm from "@/pages/news/components/edit-search-form.tsx";
import ButtonPush2Video from "@/pages/news/components/button-push2video.tsx";
import {Key} from "antd/es/table/interface";


export default function NewEdit() {
	const [editId, setEditId] = useState(-1)
	const [selectedRowKeys, setSelectedRowKeys] = useState<Id[]>([])
	const [params, setParams] = useState<ApiArticleSearchParams>({
		pagination: {page: 1, limit: 10}
	})
	const {data, refresh} = useRequest(() => getList(params), {refreshDeps: [params]})

	const columns: TableColumnsType<ListArticleItem> = [
		{
			title: '标题',
			minWidth: 300,
			dataIndex: 'title',
		},
		{
			title: '内容',
			dataIndex: 'summary',
			render: (value) => (<Typography.Paragraph style={{marginBottom: 0}} ellipsis={{
				rows: 2, expandable: true, symbol: 'More'
			}}>{value}</Typography.Paragraph>)
		},
		{
			title: '来源',
			minWidth: 150,
			dataIndex: 'media_name',
		},
		{
			title: '时间',
			width: 150,
			dataIndex: 'time',
			render: (_, record) => {
				return formatTime(record.publish_time, 'YYYY-MM-DD HH:mm')
			}
		},
		{
			title: '操作',
			width: 80,
			align: 'center',
			render: (_, record) => (<Button type="link" onClick={() => {
				setEditId(record.id)
			}}>编辑</Button>),
		},
	];

	const rowSelection: TableProps<ListArticleItem>['rowSelection'] = {
		onChange: (selectedRowKeys: Key[]) => {
			setSelectedRowKeys(selectedRowKeys as Id[])
		},
	};

	return (<div className="container pb-5 news-edit">
		<Card className="search-panel-container my-5">
			<div className="search-form flex gap-5 justify-between">
				<EditSearchForm onSubmit={setParams}/>
				<Button type="primary" onClick={() => setEditId(0)}>手动新增</Button>
			</div>
			<div className="news-list-container mt-5">
				<Table<ListArticleItem>
					rowSelection={{type: 'checkbox', ...rowSelection}}
					columns={columns}
					dataSource={data?.list || []}
					rowKey={'id'}
					bordered
					pagination={false}
				/>
				{data?.pagination && data?.pagination.total > 0 && <div className="footer flex justify-between items-center mt-5">
                    <Pagination
                        current={params.pagination.page}
                        total={data?.pagination.total}
                        pageSize={10}
                        showSizeChanger={false}
                        simple={true}
                        rootClassName={'simple-pagination'}
                        onChange={(page) => setParams(prev => ({
							...prev,
							pagination: {page, limit: 10}
						}))}
                    />
                    <ButtonPush2Video ids={selectedRowKeys} onSuccess={refresh}/>
                </div>}
			</div>
			<ArticleEditModal
				type="news" id={editId}
				onClose={(saved) => {
					setEditId(-1)
					if (saved) refresh()
				}}/>
		</Card>
	</div>)
}