import {Outlet, useNavigate} from "react-router-dom";
import {Dropdown, MenuProps} from "antd";
import React from "react";

import AuthGuard from "@/routes/layout/auth-guard.tsx";
import {LogoText} from "@/components/icons/logo.tsx";

import {UserAvatar} from "@/components/icons/user-avatar.tsx";
import {DashboardNavigation} from "@/routes/layout/dashboard-navigation.tsx";

import useAuth from "@/hooks/useAuth.ts";
import {hidePhone} from "@/util/strings.ts";


type LayoutProps = {
	children: React.ReactNode
}
const NavigationUserContainer = () => {
	const {logout,user} = useAuth()
	const navigate = useNavigate()
	const items: MenuProps['items'] = [
		{
			key: 'profile',
			label: '个人中心',
		},
		{
			key: 'logout',
			label: <div onClick={()=>{
				logout().then(()=>navigate('/user'))
			}}>退出</div>,
		},
	];
	return (<div className={"flex items-center justify-between gap-2 ml-10"}>
		<Dropdown menu={{items}} placement="bottom" arrow>
			<div className="flex items-center hover:bg-gray-100 px-2 py-1 cursor-pointer rounded">
				<UserAvatar className="user-avatar size-8"/>
				<span className={"username ml-2 text-sm"}>{hidePhone(user?.nickname)}</span>
			</div>
		</Dropdown>
	</div>)
}
export const BaseLayout: React.FC<LayoutProps> = ({children}) => {
	return (<div className={'dashboard-layout min-h-screen'}>
		<div className="min-h-screen w-full">
			<div className="app-header">
				<div className="logo-container">
					<LogoText/>
				</div>
				<div className="flex items-center">
					<DashboardNavigation/>
					<NavigationUserContainer/>
				</div>
			</div>
			<div className="app-content flex-1 box-sizing">
				<div className="content-container">
					{children}
				</div>
			</div>
		</div>
	</div>)
}


const DashboardLayout: React.FC<{ children?: React.ReactNode }> = ({children}) => {
	return <AuthGuard>
		<BaseLayout>
			{children ? children : <Outlet/>}
		</BaseLayout>
	</AuthGuard>
}
export default DashboardLayout